Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/macropad_simpletest.py
    :caption: examples/macropad_simpletest.py
    :linenos:

.. literalinclude:: ../examples/macropad_grid_layout.py
    :caption: examples/macropad_grid_layout.py
    :linenos:
